
***************************************************************************************
*This do-file (and sub do-files) creates a consumption expenditure aggregate for the Malawi IHS2 
* 
*  INPUT DATA SETS:
* 	Subcomponent data sets created by dofiles specified below
*
*  OUTPUT DATA SET:
* 	ihs2_expagg.dta
* 	ihs2_pov.dta
*
* prepared by Shelton Kanyanda, Thomas Sohnesen & Kathleen Beegle - July 2005					
*******************************************************************************************
capture log close
clear
set more off
set mem 350m	
global data     m:\po\steele\ihs2_household_data\
global dofiles  m:\po\steele\cons_agg\dofiles\
global dataoth  m:\po\steele\ihs2_auxiliary_data\
global dataoth2 m:\po\steele\cons_agg\data\
global dataoth3 m:\po\steele\cons_agg\prices\data\
global output   m:\po\steele\cons_agg\logfiles\
**************************************************************************************	

**********************************************
* NONFOOD 
**********************************************
* Section C - Education expenditures
* Section D - Health expenditures
* Section G - Utility expenditures 
* Section J-L - Nonfood
* Section M - Durables
* Section G - Housing
do "$dofiles\expagg_nonfood.do"
do "$dofiles\expagg_housing.do"
**********************************************
* FOOD VALUE
**********************************************
do "$dofiles\expagg_food0.do" 
do "$dofiles\expagg_food.do" /* revised grams for outliers, compute unit prices, compute total expenditure */
**********************************************
* GET STRATA
use $data\sec_a,clear
keep case_id strata ta ea type add hhsize
sort case
tempfile strata
save `strata'
**********************************************
log using $output\expagg,text replace
*  Mergin Sections for Consumption Expenditure Aggregate
**********************************************
use "$dataoth2\expagg_nonfood.dta" ,clear
sort case_id
merge case_id using `strata'
assert _m==3
notes drop _dta
drop _m
sort case_id
* housing file inclues price index & area variables
merge case_id using "$dataoth2\expagg_housing.dta"
assert _m==3
notes drop _dta
drop _m
drop nom* est rent* g0* g1* g2* g3* realh hous
sort case_id
merge case_id using "$dataoth2\expagg_food2.dta" 
assert _m==3
drop _m
sort case_id

gen exp_cat012=exp_cat012_i + exp_cat012_g /* drinking water in sec G */
gen exp_cat043=exp_cat043_j + exp_cat043_l
gen exp_cat045=exp_cat045_g + exp_cat045_j1 + exp_cat045_j2
gen exp_cat051=exp_cat051_k + exp_cat051_l
gen exp_cat053=exp_cat053_j2+exp_cat053_m
gen exp_cat055=exp_cat055_k +exp_cat055_m
gen exp_cat056=exp_cat056_j2+exp_cat056_k +exp_cat056_m
gen exp_cat081=exp_cat081_g +exp_cat081_j2
gen exp_cat091=exp_cat091_k +exp_cat091_l+exp_cat091_m
gen exp_cat095=exp_cat095_j1+exp_cat095_k

drop exp_cat*_* 

label var exp_cat011 "Food(nominal) Annual HH exp"
label var exp_cat012 "Beverage(nominal) Annual HH exp"
label var exp_cat021 "Alcohol(nominal) Annual HH exp"
label var exp_cat022 "Tobacco(nominal) Annual HH exp"
label var exp_cat031 "Clothing(nominal) Annual HH exp"
label var exp_cat032 "Footwear(nominal) Annual HH exp"
label var exp_cat041 "Actual rents for housing(nominal) Annual HH exp"
label var exp_cat042 "Estimated rents for housing(nominal) Annual HH exp"
label var exp_cat043 "Regular maintenance and repair of dwelling(nominal) Annual HH exp"
label var exp_cat045 "Electricity, gas, other fuels(nominal) Annual HH exp"
label var exp_cat051 "Decorations, carpets(nominal) Annual HH exp"
label var exp_cat052 "Household textiles(nominal) Annual HH exp"
label var exp_cat053 "Appliances(nominal) Annual HH exp"
label var exp_cat054 "Dishes(nominal) Annual HH exp"
label var exp_cat055 "Tools/equipment for home(nominal) Annual HH exp"
label var exp_cat056 "Routine Home maintenance(nominal) Annual HH exp"
label var exp_cat061 "Health drugs(nominal) Annual HH exp"
label var exp_cat062 "Health out-patient(nominal) Annual HH exp"
label var exp_cat063 "Health hospitalization(nominal) Annual HH exp"
label var exp_cat071 "Vehicles(nominal) Annual HH exp"
label var exp_cat072 "Operation of vehicles(nominal) Annual HH exp"
label var exp_cat073 "Transport(nominal) Annual HH exp"
label var exp_cat081 "Communications(nominal) Annual HH exp"
label var exp_cat091 "Audio-visual(nominal) Annual HH exp"
label var exp_cat092 "Major durables for rec(nominal) Annual HH exp"
label var exp_cat094 "Recreational services(nominal) Annual HH exp"
label var exp_cat095 "Newspapers, books, stationery(nominal) Annual HH exp"
label var exp_cat101 "Education (nominal) Annual HH exp"
label var exp_cat111 "Vendors/Cafes/Restaurants(nominal) Annual HH exp"
label var exp_cat112 "Accommodation services(nominal) Annual HH exp"
label var exp_cat121 "Personal care(nominal) Annual HH exp"
label var exp_cat122 "Personal effects(nominal) Annual HH exp"
label var exp_cat124 "Insurance(nominal) Annual HH exp"

********************************
* REAL EXPENDITURE AGGREGATES

qui for var exp_cat*: gen rX=X/price_index*100
label var rexp_cat011 "Food(real) Annual HH exp"
label var rexp_cat012 "Beverage(real) Annual HH exp"
label var rexp_cat021 "Alcohol(real) Annual HH exp"
label var rexp_cat022 "Tobacco(real) Annual HH exp"
label var rexp_cat031 "Clothing(real) Annual HH exp"
label var rexp_cat032 "Footwear(real) Annual HH exp"
label var rexp_cat041 "Actual rents for housing(real) Annual HH exp"
label var rexp_cat042 "Estimated rents for housing(real) Annual HH exp"
label var rexp_cat043 "Regular maintenance and repair of dwelling(real) Annual HH exp"
label var rexp_cat045 "Electricity, gas, other fuels(real) Annual HH exp"
label var rexp_cat051 "Decorations, carpets(real) Annual HH exp"
label var rexp_cat052 "Household textiles(real) Annual HH exp"
label var rexp_cat053 "Appliances(real) Annual HH exp"
label var rexp_cat054 "Dishes(real) Annual HH exp"
label var rexp_cat055 "Tools/equipment for home(real) Annual HH exp"
label var rexp_cat056 "Routine Home maintenance(real) Annual HH exp"
label var rexp_cat061 "Health drugs(real) Annual HH exp"
label var rexp_cat062 "Health out-patient(real) Annual HH exp"
label var rexp_cat063 "Health hospitalization(real) Annual HH exp"
label var rexp_cat071 "Vehicles(real) Annual HH exp"
label var rexp_cat072 "Operation of vehicles(real) Annual HH exp"
label var rexp_cat073 "Transport(real) Annual HH exp"
label var rexp_cat081 "Communications(real) Annual HH exp"
label var rexp_cat091 "Audio-visual(real) Annual HH exp"
label var rexp_cat092 "Major durables for rec(real) Annual HH exp"
label var rexp_cat094 "Recreational services(real) Annual HH exp"
label var rexp_cat095 "Newspapers, books, stationery(real) Annual HH exp"
label var rexp_cat101 "Education (real) Annual HH exp"
label var rexp_cat111 "Vendors/Cafes/Restaurants(real) Annual HH exp"
label var rexp_cat112 "Accommodation services(real) Annual HH exp"
label var rexp_cat121 "Personal care(real) Annual HH exp"
label var rexp_cat122 "Personal effects(real) Annual HH exp"
label var rexp_cat124 "Insurance(real) Annual HH exp"
label var case "HH ID"
lab var reside "Urban/Rural dummy"
lab var price_index "Spatial and temporal deflator with base national February/March 2004"
notes hhwght: To expand to national individual level multiply with hhsize
sort case
label data "Malawi IHS2 Consumption Expenditure Subcomponents by COICOP coding WITHOUT DOWA IMPUTATIONS"
qui compress
aorder
order case region reside dist hhw hhsize area type add strata ea ta pric
save "$dataoth2\ihs2_exp0.dta", replace /* WITHOUT IMPUTED VALUES FOR DOWA */

*******************************************************
* CONS AGG AND POVERTY LINES DATA SET
*******************************************************
use "$dataoth2\ihs2_exp0.dta", clear /* WITHOUT IMPUTED VALUES FOR DOWA */

* COLLAPSE TO 12 CATEGORIES FOR THE POVERTY CONS AGG WORK
gen exp_cat01=exp_cat011+ exp_cat012
gen exp_cat02=exp_cat021+ exp_cat022
gen exp_cat03=exp_cat031+ exp_cat032
* CAT04: exclude housing repairs so as not to double count housing valuation (043)
gen exp_cat04=exp_cat041+ exp_cat042+ exp_cat045
gen exp_cat05=exp_cat051+ exp_cat052+ exp_cat053+ exp_cat054+ exp_cat055+ exp_cat056
gen exp_cat06=exp_cat061+ exp_cat062+ exp_cat063
gen exp_cat07=exp_cat071+ exp_cat072+ exp_cat073
gen exp_cat08=exp_cat081
gen exp_cat09=exp_cat091+ exp_cat092+ exp_cat094+ exp_cat095
gen exp_cat10=exp_cat101
* CAT11: exclude hotels (112)
gen exp_cat11=exp_cat111
gen exp_cat12=exp_cat121+ exp_cat122+ exp_cat124

drop  exp_cat011  exp_cat012   exp_cat021   exp_cat022   exp_cat031   exp_cat032   exp_cat041   exp_cat042  
drop  exp_cat045  exp_cat051   exp_cat052   exp_cat053   exp_cat054   exp_cat055   exp_cat056   exp_cat061   exp_cat062
drop  exp_cat063  exp_cat071   exp_cat072   exp_cat073   exp_cat081   exp_cat091   exp_cat092   exp_cat094   exp_cat095
drop  exp_cat101  exp_cat111   exp_cat121   exp_cat112   exp_cat122   exp_cat124   exp_cat043
drop rexp_cat* 
qui for var exp_cat*: gen rX=X/price_index*100

label var rexp_cat01 "Food/Bev (real) Annual HH exp"
label var rexp_cat02 "Alc/Tobacco(real) Annual HH exp"
label var rexp_cat03 "Clothing/Footwear(real) Annual HH exp"
label var rexp_cat04 "Housing/Utilities(real) Annual HH exp"
label var rexp_cat05 "Furnishing(real) Annual HH exp"
label var rexp_cat06 "Health(real) Annual HH exp"
label var rexp_cat07 "Transport(real) Annual HH exp"
label var rexp_cat08 "Communications(real) Annual HH exp"
label var rexp_cat09 "Recreation(real) Annual HH exp"
label var rexp_cat10 "Education (real) Annual HH exp"
label var rexp_cat11 "Vendors/Cafes(real) Annual HH exp"
label var rexp_cat12 "Misc Goods & Services(real) Annual HH exp"
notes rexp_cat01: Food exp includes purchased, self-produced and gifts (Sec I I04,I06,I07, Sec G G35). Alcohol is excluded.  Vendor food purchases are excluded. Annualized. 
notes rexp_cat02: Alcohol (Sec I). Tobacco (Sec J). Annualized.
notes rexp_cat03: Clothing/footwear (Sec J). Annualized.	
notes rexp_cat04: Housing  rental actual/valuation (Sec G). Utility (Sec G G19&G22, Sec J 101/102/104/209, Sec M item 526).  Annualized.
notes rexp_cat06: Health (Sec D D12 D13 D14 D16 D19).  Annualized.
notes rexp_cat07: Transport (Sec M 515/516/517, Sec J 212/213/214/106). Annualized.
notes rexp_cat08: Communication (Sec J item 210, Sec G G26&G29). Annualized.
notes rexp_cat09: Recreation (Sec M items 507-509, Sec L 406, Sec K 334-337, Sec J 105). Annualized.
notes rexp_cat10: Education exp (Sec C C30).  Annualized.
notes rexp_cat11: Vendors/Cafes (Sec I 820-830).  Annualized.
notes rexp_cat12: Misc goods (Sec J personal items, Sec L 410 insurance).Annualized.
gen rexpagg=rexp_cat01+rexp_cat02+rexp_cat03+rexp_cat04+rexp_cat05+rexp_cat06+rexp_cat07+rexp_cat08+rexp_cat09+rexp_cat10+rexp_cat11+rexp_cat12
label var rexpagg  "Total Annual HH exp"
notes rexpagg: Sum of rexp_cat 0-12 (real HH expenditure in categories 01-12)
drop exp_cat*
tempfile  ihs2_pov
save `ihs2_pov'
********************************************************************************************
*  Poverty Line
** SET FPL REFERENCE POPULATION
local  decilelow=5
local  decilehi =6

********************************************************************************************
* COMPUTE THE AVERAGE CALORIE REQUIRMENTS OF THE POPULATION BASED ON WHO SCALE
use "$dataoth\ihs2_individ", clear
keep case age
merge case using "$dataoth\ihs2_household"
assert _m==3
keep case age hhw hhsize
* MEDIAN CALORIE REQUIREMENTS BASED ON WHO 1985 REPORT (ALSO AS USED IN ZAMBIA WORK)
*<1		820		
*1-2		1150		
*2-3		1350		
*3-5		1550		
*5-7		1800	
*7-10		1950	
*10-12	2075	
*12-14	2250	
*14-16	2400	
*16-18	2500	
*18+		2464	
assert age~=.
gen     calories=820 if age<1
replace cal=1150 if age>=1 & age<2
replace cal=1350 if age>=2 & age<3
replace cal=1550 if age>=3 & age<5
replace cal=1800 if age>=5 & age<7
replace cal=1950 if age>=7 & age<10
replace cal=2075 if age>=10& age<12
replace cal=2250 if age>=12& age<14
replace cal=2400 if age>=14& age<16
replace cal=2500 if age>=16& age<18
replace cal=2464 if age>=18& age<.
sum calo [w=hhw*hhs]
gen cal_med=calo
collapse (mean) calo (median) cal_med [w=hhw*hhsize]
sum
qui for var calo cal_m: replace X=round(X,1)
sum
local calories=cal_med
di `calories'

********************************************************************************************
* GENERATES CALORIE CONSUMPTION PER HOUSEHOLD
use 	"$dataoth2\expagg_food1",clear
sort 	i02
merge i02 using "$dataoth2\IHS2calories"
assert _m==3
drop 	_m item_d  item_ihs 
bys 	case i02: assert _n==1

gen 	cal_per_hh=sec_i_grams*(cal_100g/100) * (edible_p/100)		/*weekly calorie in-take*/
sort 	case i02

collapse (sum) cal_per_hh, by(case)							/*(sum) cal_item*/
lab 	var cal_per_hh "Calories per week for all in hh" 

compress
sort case
tempfile cal_total
save 	`cal_total'

********************************************************************************************
* CONSUMPTION DECILES: BASED ON REAL, POP-WEIGHTED TOTAL PER CAP CONSUMPTION
use 	`ihs2_pov'

* FOOD & NONFOOD EXPENDITURE 
gen rexpfood=(rexp_cat01+rexp_cat11)
gen rexpnfd = (rexp_cat02+rexp_cat03+rexp_cat04+rexp_cat05+rexp_cat06+rexp_cat07+rexp_cat08+rexp_cat09+rexp_cat10+rexp_cat12)
gen diff= rexpfood+rexpnf-rexpagg
assert abs(diff)<.2

* FOOD PER CAPITA EXPENDITURE
gen 	fd_exp_pc=(rexpfood)/hhsize

* TOTAL PER CAPITA EXPENDITURE
gen 	exp_pc=rexpagg/hhsize
assert exp_pc~=.

* NONFOOD PER CAPITA EXPENDITURE
gen 	nfd_exp_pc=(rexpnfd)/hhsize

* DECILES FOR PC CONSUMPTION
xtile decile = exp_pc [w=hhw*hhsize], nq(10)

* merge in cost per calorie info
merge case using `cal_total'
assert _m==3

* CALORIES PER PERSON PER DAY
gen cal_pp_day=cal_per_hh/7/hhsize
sum cal_pp_day,d
table strata, c(mean cal_pp_day median cal_pp_day)

* annual hh real food expenditure divided by total calories per week*52 *
gen cost_per_calorie=(rexp_cat01+rexp_cat11)/(cal_per_hh*52) 			

* COST PER CALORIE BY DECILES
preserve
gen cost_cal=cost_per_cal*1000
tab decile [w=hhs*hhw], sum(cost_cal)
bys decile : sum cost_cal [w=hhs*hhw],det
collapse (mean) cost_cal cost_per_cal  [w=hhs*hhw], by(decile)
replace cost_cal=round(cost_cal,.01)
* already weighted
tab decile , sum(cost_per_cal)
tab decile , sum(cost_cal)
restore

* COST PER CALORIE FOR REFERENCE POPULAITON 
egen temp = median(cost_per_calorie)  if (decile >= `decilelow' & decile <= `decilehi')
tab decile  [iw=hhs*hhw] if (decile >= `decilelow' & decile <= `decilehi')
sum cost_per_cal [w=hhs*hhw] if (decile >= `decilelow' & decile <= `decilehi'),det

egen cal_povline=max(temp)
replace cal_povline=round(cal_povline,.00001)
sum cal_povline

* FOOD POVERTY LINE: COST FOR CALORIES PER PERSON PER YEAR
di `calories'
gen fpl=cal_povline*7*52*`calories'
replace fpl=round(fpl,1)
lab var fpl   "Ultra Poverty Line MK per person per year"
notes fpl: Food Poverty Line.  Calories 2400.  Ref Pop deciles 5&6.
lab var rexpfood "Food Annual HH Exp"
lab var rexpnfd  "NonFood Annual HH Exp"
lab var decile   "Decile Exp PerCap weighted"
notes decile: population weighted expenditure per cap (rexpagg/hhsize) decile.
keep case fpl exp_pc fd_exp_pc nfd_exp_pc rexpfood rexpnf decile
compress
sort case_id
tempfile fpl
save `fpl'

********************************************************************
* GENERATING THE NON-FOOD COMPONENT OF THE POVERTY LINE
********************************************************************
use `fpl', clear
sort case_id
merge case using `ihs2_pov'
assert _m==3
drop _merge
order region reside case

*CALCULATING "KERNEL" WEIGHTED NON-FOOD POVERTY LINE WITH HIGHEST WEIGHT GIVEN TO HOUSEHOLDS NEAR FOOD POVERTY LINE
*GENERATING UPPER AND LOWER BOUNDERIES 
gen upper10  = fpl + (fpl*(5/100))
gen lower10  = fpl - (fpl*(5/100))
gen upper8   = fpl + (fpl*(4/100))
gen lower8   = fpl - (fpl*(4/100))
gen upper6   = fpl + (fpl*(3/100))
gen lower6   = fpl - (fpl*(3/100))
gen upper4   = fpl + (fpl*(2/100))
gen lower4   = fpl - (fpl*(2/100))
gen upper2   = fpl + (fpl*(1/100))
gen lower2   = fpl - (fpl*(1/100))

gen foodshare=rexpfood/rexpagg
tab decile [w=hhw*hhs], sum(foodsh) 

*CALCULATES MEDIAN NON FOOD EXPENDITURES PER CAPITA BY BOUNDERIES
* NOTE: TAKING MEAN VALUES GIVES LARGER NONFOOD SHARES
* EXAMPLE:
egen temp_mean=mean(nfd_exp_pc) if fd_exp_pc>lower10 & fd_exp_pc<upper10
gen x=(exp_pc-temp_mean)/(exp_pc)
sum  foodshare x if fd_exp_pc>lower10 & fd_exp_pc<upper10
drop x temp_mean

egen temp1=median(nfd_exp_pc) if fd_exp_pc>lower10 & fd_exp_pc<upper10
gen fdshare=(exp_pc-temp1)/(exp_pc)
sum  foodshare fdshare if fd_exp_pc>lower10 & fd_exp_pc<upper10
drop fdshare
egen temp2=median(nfd_exp_pc) if fd_exp_pc>lower8  & fd_exp_pc<upper8
gen fdshare=(exp_pc-temp2)/(exp_pc)
sum  foodshare fdshare if fd_exp_pc>lower8  & fd_exp_pc<upper8 
drop fdshare
egen temp3=median(nfd_exp_pc) if fd_exp_pc>lower6  & fd_exp_pc<upper6
gen fdshare=(exp_pc-temp3)/(exp_pc)
sum  foodshare fdshare if fd_exp_pc>lower6  & fd_exp_pc<upper6
drop fdshare
egen temp4=median(nfd_exp_pc) if fd_exp_pc>lower4  & fd_exp_pc<upper4
gen fdshare=(exp_pc-temp4)/(exp_pc)
sum  foodshare fdshare if fd_exp_pc>lower4  & fd_exp_pc<upper4 
drop fdshare
egen temp5=median(nfd_exp_pc) if fd_exp_pc>lower2  & fd_exp_pc<upper2
gen fdshare=(exp_pc-temp5)/(exp_pc)
sum  foodshare fdshare if fd_exp_pc>lower2  & fd_exp_pc<upper2 
drop fdshare

*TAKES MEAN OF mean VALUES TO GIVE "KERNEL" WEIGHTED AVERAGE
egen temp = rmean( temp1 temp2 temp3 temp4 temp5)
*GENERATE NON FOOD POVERTY LINE
egen nfdpl=mean(temp)
replace nfdpl=round(nfdpl,1)
gen fdsh_pl=fpl/(fpl+nfdpl)
* check that food share in poverty line is about 60%: rough average for the ref pop
sum fdsh
drop temp* fdsh

*GENERATES TOTAL POVERTY LINE
gen povline=fpl+nfdpl
ren fpl ultrapovline

* IDENTIFY POOR & ULTRA POOR
gen poor =(exp_pc<povline) if exp_pc~=.
gen ultra_poor =(exp_pc<ultrapovline) 

keep  ultra_poor poor case_id povline ultrap rexpfood rexpnfd decile

lab define poor 1 "Poor" 0 "Non-Poor"
lab val poor poor
label var poor    "Exp per cap< poverty line"
label var ultra_p "Exp per cap< ultra pov line"
lab define ultra_p 1 "Ultra Poor" 0 "Non-Poor"
lab val ultra_poor ultra_p
lab var povline  "Poverty Line MK pp pa"
notes poor: 1 if poor.  0 otherwise. (rexpagg/hhsize)<povline
notes povl: ultra poverty line + nonfood basic needs

sort case

qui merge case using `ihs2_pov'
assert _m==3
drop _m

** DEFINE SAMPLE DESIGN VARIABLES **
gen str8 EA=substr(case,1,8)
label var EA "8 digit EA  number (DIST+TA+EA) (564 PSUs total)"

************************
* SHOULD HAVE 30 STRATA
preserve
bys strata: drop  if _n>1
assert _N==30
restore
* SHOULD HAVE 564 EAS 
preserve
bys EA: drop  if _n>1
assert _N==564
restore
************************

sort case
compress
label data "Malawi IHS2 Annual Cons Exp Aggregate, Pov Lines, Pov Indicators WITHOUT DOWA IMPUTATIONS"
label var case "HH ID variable"
order case region reside dist hhw hhsize area type add strata ta ea EA poor ultra_p decile rexpa rexpf rexpn rexp_c* povl  ultrapov price_
save "$dataoth2\ihs2_pov0.dta", replace  /* WITHOUT IMPUTED VALUES FOR DOWA */

********************************************************************
********************************************************************
* MERGE IN DOWA IMPUTATIONS
********************************************************************
use "$dataoth2\ihs2_pov0.dta", clear  /* WITHOUT IMPUTED VALUES FOR DOWA */
tab dist if dist==204
drop if dist==204
qui append using "$dataoth2\ihs2_pov_dowa.dta"
label data "Malawi IHS2 Annual Cons Exp Aggregate, Pov Lines, Pov Indicators"
order case region reside dist hhw hhsize area type add strata ta ea EA poor ultra_p decile rexpa rexpf rexpn rexp_c* povl  ultrapov price_
sort case
save "$dataoth2\ihs2_pov.dta", replace  /* WITH IMPUTED VALUES FOR DOWA */

use "$dataoth2\ihs2_exp0.dta", clear  /* WITHOUT IMPUTED VALUES FOR DOWA */
tab dist if dist==204
drop if dist==204
qui append using "$dataoth2\ihs2_exp_dowa.dta"
label data "Malawi IHS2 Consumption Expenditure Subcomponents by COICOP coding"
order case region reside dist hhw hhsize area type add strata ea ta pric
sort case
save "$dataoth2\ihs2_exp.dta", replace  /* WITH IMPUTED VALUES FOR DOWA */

log close

use "$dataoth2\ihs2_pov.dta",clear
sum povline
use "$dataoth2\ihs2_pov0.dta",clear
sum povline






