*******************************************************************************************      
*******************************************************************************************      
* REVISED GRAMS OF FOOD CONSUMED IN LAST 7 DAYS - Section I
* COMPUTE UNIT PRICES
* CALCULATE FOOD EXPENDITURE
*
*  INPUT DATA SETS:
*    	expagg_food0.dta
*     ihs2calories.dta
* 	ihs2_household.dta
* 	sec_a
* 	 
*  OUTPUT DATA SETS:
* 	expagg_food1.dta : grams and exp for each food item & household
* 	expagg_food2.dta : exp for each household by 4 COICOP categories
* 
*******************************************************************************************      
*******************************************************************************************
capture log close
clear
set more off
set mem 300m

log using "$output\expagg_food", text replace

*******************************************
* original grams data file
use $dataoth2\expagg_food0, clear

* GRAMS : START FROM THE OLD VERSION
gen sec_i_grams = sec_i_grams0

sort i02
merge i02 using $dataoth2\IHS2calories, _merge(merge1)
assert merge1==3
bys case_id i02: assert _n==1
sort i02
drop merge* item_d item_ihs
g maize=1 if i02>=101 & i02<=104
g grams_maize=sec_i_grams if maize==1
g cal_per_hh_maize=sec_i_grams*(cal_100g/100) * (edible_p/100) if maize==1
*******************************************
* SOME CORRECTIONS ON GRAMS OF FISH CONSUMED IN KARONGA AND NKHATA BAY 
tab sec_i_grams if sec_i_grams>0&i02==502
sum sec_i_grams if sec_i_grams>0&sec_i_grams<2500&i02==502, d
replace sec_i_grams=320 if sec_i_grams>2500&sec_i_grams<.&i02==502
tab sec_i_grams if sec_i_grams>0&i02==503
sum sec_i_grams if sec_i_grams>0&sec_i_grams<15000&i02==503, d
replace sec_i_grams=2751 if sec_i_grams>15000&sec_i_grams<.&i02==503
*******************************************
preserve
* CORRECTIONS ON MAIZE
collapse (sum) grams* cal*, by(case_id)       /* (sum) by case_id */
mvdecode grams_maize, mv(0) 
sort case_id
merge case_id using $dataoth\ihs2_household, _merge(merge1) keep(hhsize idate dist)
assert merge1==3
drop merge*
*******************************************
* DATE OF INTERVIEW 
g month_int=month(idate)
la de month 1 "January" 2 "February" 3 "March" 4 "April" 5 "May" 6 "June" 7 "July" 8 "August" 9 "September" 10 "October" /*
*/11 "November" 12 "December"
la val month_int month
g year_int=year(idate)
g date_int=month_int*10000+year_int 
replace date_int=1 if date_int==32004
replace date_int=2 if date_int==42004
replace date_int=3 if date_int==52004
replace date_int=4 if date_int==62004
replace date_int=5 if date_int==72004
replace date_int=6 if date_int==82004
replace date_int=7 if date_int==92004
replace date_int=8 if date_int==102004
replace date_int=9 if date_int==112004
replace date_int=10 if date_int==122004
replace date_int=11 if date_int==12005
replace date_int=12 if date_int==22005
replace date_int=13 if date_int==32005
la de date_int 1 "March04" 2 "April04" 3 "May04" 4 "June04" 5 "July04" 6 "August04" 7 "September04" 8 "October04" /*
*/9 "November04" 10 "December04" 11 "January05" 12 "February05" 13 "March05" 
la val date_int date_int 
la var date_int "date of interview"
*******************************************
* DETECTING "DOWNLIERS" AND OUTLIERS 
* AND COMPUTING MEDIAN BY MONTH 
g grams_maize_pc=((grams_maize/hhsize)/7)
g downlier=grams_maize_pc<100
g outlier=grams_maize_pc>600&grams_maize_pc<.
la var grams_maize_pc "daily pc-grams of maize"
la var downlier "HH has daily pc-grams of maize <100"
la var outlier "HH has daily pc-grams of maize >600"
bys date_int: egen temp_maize=median(grams_maize) if dist!=102&dist!=103
bys date_int: egen med_maize=max(temp_maize)
bys date_int: egen temp2_maize=median(grams_maize) if dist!=102&dist!=103
replace temp2_maize=temp2_maize/2
bys date_int: egen med2_maize=max(temp2_maize)
bys date_int: egen temp2_3_maize=median(grams_maize) if dist!=102&dist!=103
replace temp2_3_maize=temp2_3_maize*2/3
bys date_int: egen med2_3_maize=max(temp2_3_maize)
drop temp*
la var med_maize "median of maize consumed by month per hh (grams)" 
la var med2_maize "median/2 of maize consumed by month per hh (grams)" 
la var med2_3_maize "median*(2/3) of maize consumed by month per hh (grams)" 
bys date_int: egen temp_cal_maize=median(cal_per_hh_maize) if dist!=102&dist!=103
bys date_int: egen med_cal_maize=max(temp_cal_maize)
bys date_int: egen temp2_cal_maize=median(cal_per_hh_maize) if dist!=102&dist!=103
replace temp2_cal_maize=temp2_cal_maize/2
bys date_int: egen med2_cal_maize=max(temp2_cal_maize)
bys date_int: egen temp2_3_cal_maize=median(cal_per_hh_maize) if dist!=102&dist!=103
replace temp2_3_cal_maize=temp2_3_cal_maize*2/3
bys date_int: egen med2_3_cal_maize=max(temp2_3_cal_maize)
drop temp*
la var med_cal_maize "median of maize consumed by month per hh (calories)" 
la var med2_cal_maize "median/2 of maize consumed by month per hh (calories)" 
la var med2_3_cal_maize "median*(2/3) of maize consumed by month per hh (calories)" 
keep case_id med_maize-med2_3_maize *lier date*
qui compress
sort case_id
tempfile median
save `median'
*******************************************
restore
sort case_id
merge case_id using `median', _merge(merge1)
assert merge1==3
drop merge*
*******************************************
* CORRECTIONS ON MAIZE 
sort case_id i02
by case_id: g maize_1=_n==1 if maize==1
by case_id: egen grams_maize_max=max(sec_i_grams) if maize==1
g sec_i_grams_m=sec_i_grams
replace sec_i_grams_m=0 if maize==1
replace sec_i_grams_m=sec_i_grams if downlier==0
replace sec_i_grams_m=med_maize if maize==1&downlier==1&(sec_i_grams==grams_maize_max)
*replace sec_i_grams_m=med_maize if outlier==1&((sec_i_grams==grams_maize_max)&(sec_i_grams>med_maize))
g sec_i_grams_2=sec_i_grams
replace sec_i_grams_2=0 if maize==1
replace sec_i_grams_2=sec_i_grams if downlier==0
replace sec_i_grams_2=med2_maize if maize==1&downlier==1&(sec_i_grams==grams_maize_max)
*replace sec_i_grams_2=med2_maize if outlier==1&((sec_i_grams==grams_maize_max)&(sec_i_grams>med2_maize))
g sec_i_grams_2_3=sec_i_grams
replace sec_i_grams_2_3=0 if maize==1
replace sec_i_grams_2_3=sec_i_grams if downlier==0
replace sec_i_grams_2_3=med2_3_maize if maize==1&downlier==1&(sec_i_grams==grams_maize_max)
*replace sec_i_grams_2_3=med2_3_maize if outlier==1&((sec_i_grams_m==sec_i_grams_max1)&(sec_i_grams>med2_3_maize))
*******************************************
*  SAVING A FILE OF HOUSEHOLDS NOT REPORTING MAIZE 
* CONSUMPTION (SO ==0) WHICH IS REPLACED BY THE MEDIAN BY MONTH 
preserve
g grams_maize_m=sec_i_grams_m if maize==1
g grams_maize_2=sec_i_grams_2 if maize==1
g grams_maize_2_3=sec_i_grams_2_3 if maize==1
collapse (sum) cal_per_hh* grams*, by(case_id)       /* (sum) by case_id */
sort case_id
merge case_id using `median', _merge(merge1)
tab merge1
drop merge*
replace grams_maize=med_maize if grams_maize==0
keep if grams_maize_m==0
g i02=101
la var i02 "ITEM CODE"
keep case_id i02 grams_maize 
ren grams_maize sec_i_grams
* sec_i_grams for these households: Total grams on food item by hh (zeros replaced by median)
order case_id i02 sec_i_grams
qui compress
sort case_id i02
tempfile hh_nonreporting_maize
save `hh_nonreporting_maize'
restore

*******************************************
* WARNING: READ CAREFULLY! 
drop sec_i_grams
ren sec_i_grams_m sec_i_grams     /* DEFAULT: REPLACING THE MEDIAN */
* ren sec_i_grams_2 sec_i_grams   /* REPLACING HALF OF THE MEDIAN */
* ren sec_i_grams_2_3 sec_i_grams /* REPLACING 2/3 OF THE MEDIAN */
*******************************************
keep case_id i02 sec_i_grams0 sec_i_grams seci_grams_0* i05
bys case i02: assert _n==1
*******************************************
* Append in the replaced zero values
append using `hh_nonreporting_maize'
bys case i02: gen dup=(_N>1)
list if (case=="10508012281"| case=="10508012304"|case=="20806012022")
drop if (case=="10508012281"| case=="10508012304"|case=="20806012022") & sec_i_grams==0 & dup==1
drop dup
bys case i02: assert _n==1
*******************************************
* NOTE THAT SOME REVISED GRAMS ARE 0
list if sec_i_grams==0 & sec_i_grams0~=0,noobs

* REPLACE WITH ORIGINAL, NON ZERO VALUE
replace sec_i_grams=sec_i_grams0 if sec_i_grams==0 & sec_i_grams0~=0

label var sec_i_grams "Total grams on food item (Revised)"
keep case_id i02 sec_i_grams* i05* seci_grams_0*
bys case i02: assert _n==1
tempfile food
save `food'

*******************************************************************************************      
*******************************************************************************************
* UNIT PRICES
**************************************
*MONTH OF INTERVIEW IN DATA, DISTRICT AND AREA
use "$data\sec_a", clear
ren a14b month
ren a14c year
sort case
gen area=.
replace area=1 if reside==0
replace area=2 if region==1 & area==.
replace area=3 if region==2 & area==.
replace area=4 if region==3 & area==.
lab var area "Geographical Area"
lab def area  1 "Urban" 2 "Rural North" 3 "Rural Centre" 4 "Rural South"
lab values area area
sort case
keep month year case area dist
sort case 
tempfile month
save `month'
**************************************
use `food'
merge case_id using `month'
assert _m==3
drop _m
* GENERATING UNITPRICE BASED ON PRODUCTS BOUGHT
gen     i05_price=i05_exp/(seci_grams_05) 				
replace i05_price=. if i05_price==0
gen unitprice=i05_price
*GENERATING VALUES FOR REPLACEMENT OF OUTLIERS
bys i02 dist month year : egen p1=median (i05_price)		
bys i02 area month year : egen p2=median (i05_price)		
bys i02 area		: egen p3=median (i05_price)	
bys i02			: egen p4=median (i05_price)		
*COUNTING NUMBER OF PRICE OBSERVATIONS BY AREAS 
bys i02 dist month year	:egen c1=count (i05_price)		
bys i02 area month year	:egen c2=count (i05_price)		
bys i02 area		:egen c3=count (i05_price)	
bys i02			:egen c4=count (i05_price)		
*NOT USING UNITS PRICES FOR AREAS WITH LESS THAN 7 OBSERVATIONS
replace p1=. if c1<7
replace p2=. if c2<7
replace p3=. if c3<7
gen pnat=p1
replace pnat=p2 if pnat==.
replace pnat=p3 if pnat==.
replace pnat=p4 if pnat==.
***OUTLIERS
*graphical outliers removal 
replace unitprice=pnat if i02==101 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==102 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==103 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==104 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==105 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==106 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==107 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==108 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==109 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==110 & unitprice>=0.4 & unitprice~=.
replace unitprice=pnat if i02==111 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==112 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==113 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==114 & unitprice>=1.5 & unitprice~=.
replace unitprice=pnat if i02==115 & unitprice>=1.5 & unitprice~=.

replace unitprice=pnat if i02==201 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==202 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==203 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==204 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==205 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==206 & unitprice>=5 & unitprice~=.

replace unitprice=pnat if i02==301 & unitprice>=0.4 & unitprice~=.
replace unitprice=pnat if i02==302 & unitprice>=0.4 & unitprice~=.
replace unitprice=pnat if i02==303 & unitprice>=0.4 & unitprice~=.
replace unitprice=pnat if i02==304 & unitprice>=0.4 & unitprice~=.
replace unitprice=pnat if i02==305 & unitprice>=0.4 & unitprice~=.
replace unitprice=pnat if i02==306 & unitprice>=0.4 & unitprice~=.
replace unitprice=pnat if i02==307 & unitprice>=0.4 & unitprice~=.

replace unitprice=pnat if i02==401 & unitprice>=3 & unitprice~=.
replace unitprice=pnat if i02==403 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==404 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==405 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==406 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==407 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==410 & unitprice>=0.05 & unitprice~=.

replace unitprice=pnat if i02==501 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==502 & unitprice>=3 & unitprice~=.
replace unitprice=pnat if i02==503 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==504 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==505 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==506 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==507 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==509 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==510 & unitprice>=2 & unitprice~=.
replace unitprice=pnat if i02==511 & unitprice>=2 & unitprice~=.

replace unitprice=pnat if i02==602 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==606 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==608 & unitprice>=0.2 & unitprice~=.

replace unitprice=pnat if i02==701 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==702 & unitprice>=2 & unitprice~=.
replace unitprice=pnat if i02==703 & unitprice>=1.5 & unitprice~=.
replace unitprice=pnat if i02==704 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==705 & unitprice>=0.4 & unitprice~=.
replace unitprice=pnat if i02==706 & unitprice>=2 & unitprice~=.
replace unitprice=pnat if i02==707 & unitprice>=2 & unitprice~=.
replace unitprice=pnat if i02==708 & unitprice>=1 & unitprice~=.

replace unitprice=pnat if i02==801 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==802 & unitprice>=0.02 & unitprice~=.
replace unitprice=pnat if i02==803 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==810 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==811 & unitprice>=3 & unitprice~=.
replace unitprice=pnat if i02==812 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==813 & unitprice>=3 & unitprice~=.
replace unitprice=pnat if i02==814 & unitprice>=3 & unitprice~=.
replace unitprice=pnat if i02==816 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==821 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==822 & unitprice>=0.05 & unitprice~=.
replace unitprice=pnat if i02==824 & unitprice>=2 & unitprice~=.
replace unitprice=pnat if i02==826 & unitprice>=0.5 & unitprice~=.
replace unitprice=pnat if i02==829 & unitprice>=0.5 & unitprice~=.

replace unitprice=pnat if i02==901 & unitprice>=1.5 & unitprice~=.
replace unitprice=pnat if i02==902 & unitprice>=3 & unitprice~=.
replace unitprice=pnat if i02==903 & unitprice>=2 & unitprice~=.
replace unitprice=pnat if i02==904 & unitprice>=1 & unitprice~=.
replace unitprice=pnat if i02==905 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==906 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==907 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==908 & unitprice>=0.4 & unitprice~=.
replace unitprice=pnat if i02==909 & unitprice>=0.2 & unitprice~=.
replace unitprice=pnat if i02==910 & unitprice>=0.1 & unitprice~=.
replace unitprice=pnat if i02==912 & unitprice>=0.4 & unitprice~=.

gen lunitprice=log(unitprice)
bys i02:egen sd=sd(lunitprice)
bys i02:egen mean=mean(lunitprice)

*this rule follows deaton 2000 & Whelan 2005  
bys i02:gen limit=2.5*sd
bys i02:gen upper=mean+limit
bys i02:gen lower=mean-limit
bys i02:gen tag=1 if ((lunitprice>upper & lunitprice~=.)|lunitprice<lower)
replace unitprice=pnat if tag==1

*GENERATING PRICES FOR PRODUCTS CONSUMED BASED ON PRODUCTS BOUGHT
replace unitprice=pnat if unitprice==.

drop tag pnat p1 p2 p3 p4 c1 c2 c3 c4 lunit sd mean limi upper lowe 
label var i05_price "Unit price paid by household if bought (I05)"
label var unitprice "Unit price for hh (price paid, else assigned by location)"
qui compress
sort case i02 
order case i02 seci_grams* sec_i* i05* unit
tempfile unitprice
save `unitprice'

* CREATE UNIT PRICE FILE FOR GERO
use `unitprice'
drop if unitprice==. & (i02==117|i02==209|i02==309|i02==413|i02==512|i02==610|i02==709|i02==804|i02==817|i02==830|i02==913)
assert unitp~=.
keep case i02 unitprice month year area dist
sort case i02
label data "Unit prices on Sec I items, excl others"
save $dataoth2\ihs2_unitprices,replace


***********************************************************
* COMPUTE EXPENDITURE FOR HOME PRODUCTION/GIFTS (I06 & I07)
***********************************************************
use `unitprice',clear

gen i06_exp=seci_grams_06*unitprice
gen i07_exp=seci_grams_07*unitprice

* OTHER FOOD ITEMS
* generate food categories
gen foodcat = . 								
replace foodcat = 1 if (i02 >= 101 & i02 <= 117)
replace foodcat = 2 if (i02 >= 201 & i02 <= 209)
replace foodcat = 3 if (i02 >= 301 & i02 <= 309)
replace foodcat = 4 if (i02 >= 401 & i02 <= 413)
replace foodcat = 5 if (i02 >= 501 & i02 <= 512)
replace foodcat = 6 if (i02 >= 601 & i02 <= 610)
replace foodcat = 7 if (i02 >= 820 & i02 <= 830)
replace foodcat = 8 if (i02 >= 701 & i02 <= 709)
replace foodcat = 9 if (i02 >= 801 & i02 <= 804)
replace foodcat = 10 if (i02 >= 901 & i02 <= 913)
replace foodcat = 11 if (i02 >= 810 & i02 <= 817)
bys foodcat month year dis area: egen i_06p = median(i06_exp)
bys foodcat month year dis area: egen i_07p = median(i07_exp)
* Assign median values for food type for "other" foods for which MK are not computed
qui for var i06_exp i07_exp: assert X==. if (i02==117|i02==209|i02==309|i02==413|i02==512|i02==610|i02==830|i02==709|i02==804|i02==913|i02==817)
replace i06_exp  = i_06p if (i02==117|i02==209|i02==309|i02==413|i02==512|i02==610|i02==830|i02==709|i02==804|i02==913|i02==817)
replace i07_exp  = i_07p if (i02==117|i02==209|i02==309|i02==413|i02==512|i02==610|i02==830|i02==709|i02==804|i02==913|i02==817)

* TOTAL EXPENDITURE IN THE LAST 7 DAYS
egen exp_seci= rsum(i05_exp i06_exp i07_exp) 
* Identify households with outliers reassigned
gen diff=sec_i_grams0- sec_i_grams
replace diff=0 if abs(diff)<.0004
replace diff=1 if diff~=0
tab dis diff,m
tab i02 diff,m
* for households with outliers reassigned, re-compute total expenditure
replace exp_seci=sec_i_grams*unitprice if diff==1
label var exp_seci "Total expenditure on item in last 7 days"
drop diff i_06p i_07p year month dist foodcat area i06_exp i07_exp
order case i02 exp_seci sec* seci_grams* i05* unit
sort case i02
by case i02: assert _n==1
qui compress
save $dataoth2\expagg_food1,replace

*******************************************************************************************      
*******************************************************************************************
use $dataoth2\expagg_food1,clear
* EXPENDITURE CATEGORIES: BEVERAGE, ALCOHOL, VENDOR, FOOD
gen exp_cat012_i= exp_seci if (i02>=901  & i02<=906)|(i02==913) 			/* beverage */ 
gen exp_cat021  = exp_seci if i02>=907 & i02<=912  					/* alcohol 	*/
gen exp_cat111  = exp_seci if i02>=820 & i02<=830  					/* vendor 	*/
gen exp_cat011  = exp_seci if  exp_cat012==. & exp_cat021==. & exp_cat111==.	/* food 	*/
collapse (sum) exp_cat*, by(case)
qui for var exp_cat*: replace X=X*52
label var exp_cat012 "beverage expenditure last year Sec I"
label var exp_cat021 "alcohol expenditure last year Sec I"
label var exp_cat111 "vendor expenditure last year Sec I"
label var exp_cat011 "food, non-vendor expenditure last year Sec I"
sort case
qui compress
save $dataoth2\expagg_food2, replace

log close
