***************************************************************************************
* expagg_housing.do
* This do-file creates consumption expenditure aggregate for housing
* 
*  INPUT DATA SETS:
*    	sec_g.dta , sec_a.dta (Original data)
*	price_index (needed to run regressions to estimate missing rents)
*      
*  OUTPUT DATA SET:
* 	expagg_housing.dta
*
*******************************************************************************************
capture log close
set more off
log using "$output\expagg_housing",text replace

****************************************************************************************************
* SECTION A
* DATE OF INTERVIEW TO MERGE IN PRICE DEFLATOR WHICH WILL BE USED TO DELFATE AND THEN ESTIMATE RENTAL VALUES FOR MISSING OBS (N=108)
****************************************************************************************************
use "$data\sec_a.dta", clear
* correction
replace a14c=2004 if a14c==2003
ren a14c year
ren a14b month
replace month=3 if year==2005 & (month==4 | month==5)
list month year case if substr(case,1,8)=="30203062",noobs
replace year=2005 if month==1 & year==2004 & substr(case,1,8)=="30203062"
list month year case if substr(case,1,8)=="30306047",noobs
replace month=8 if month==. & substr(case,1,8)=="30306047"
replace year=2004 if year==. & substr(case,1,8)=="30306047"
assert month~=. & year~=.
keep case year month
sort month year
tempfile idate
save `idate'

**************************************************
* SECTION G
* ACTUAL AND ESTIMATED RENTS
**************************************************
use "$data\sec_g.dta", clear
* corrections g01: is 0 for one household.  Assume it is 1 since they report estimated rent
list g02 g03* g04* g05 g06 if g01==0
replace g01=1 if g01==0

*****************************************
* ESTIMATED RENT
*****************************************
* corrections g03: estimated rent with out of range time units
replace g03b=. if g03b~=3 & g03b~=4 & g03b~=5 & g03b~=6 & g03a~=. 

sum g03a if g03b~=3 & g03b~=4 & g03b~=5 & g03b~=6 & g03a~=. ,det

* daily 
replace g03b=3 if g03b==. & g03a==5
* weekly
replace g03b=4 if g03b==. & g03a<100 & g03a>5
* monthly 
replace g03b=5 if g03b==. & g03a>=100 & g03a<1000
* annual
replace g03b=6 if g03b==. & g03a>=1000 & g03a<.
assert g03b~=. if g03a~=.

bys g03b: sum g03a,det

* annual estimated rentals
gen nomest_rent=.							
replace nomest_rent=g03a*365 if g03b==3
replace nomest_rent=g03a*52  if g03b==4
replace nomest_rent=g03a*12  if g03b==5
replace nomest_rent=g03a	  if g03b==6
* number of cases missing estimated rent
count if g01~=6 & nomest==.

*****************************************
* ACTUAL RENT 
*****************************************
* corrections g04: estimated rent with out of range time units
replace g04b=. if g04b~=3 & g04b~=4 & g04b~=5 & g04b~=6 & g04a~=. 
sum g04a if g04b~=3 & g04b~=4 & g04b~=5 & g04b~=6 & g04a~=. ,det
replace g04b=5 if g04b==. & g04a<=1000
replace g04b=6 if g04b==. & g04a>1000 & g04a~=.
replace g04b=5 if g04b==6 & g04a==200			/*the reported value is too small for an annual fee (MK200)*/
replace g04b=6 if g04b==5 & g04a~=. & g04a>=10000	/*the reported value is too large for a monhtly rent */
assert g04b==5 | g04b==6 if g04a~=.

* annual actual rents
gen nomrent=.							/*generating annual cumulative rentals)*/	   
replace nomrent=g04a*12 	if g04b==5  		/* if unit reported is one month */
replace nomrent=g04a		if g04b==6  		/* if unit reported is one year */
* number of cases missing actual rent
count if g01==6 & nomrent==.
******************************************
* CHECK DATA: can't have both estimates and actual rent
******************************************
assert nomest==. if nomrent~=.
assert nomrent==. if nomest~=.
assert g01==6 if nomrent~=.
assert g01>=1 & g01<6 if nomest~=.
tab g01, sum(nomest)
tab g01, sum(nomrent)

gen renting=(g01==6) if g01<7 
label variable renting "1=renting else 0=not renting"

*********************************************************************************
* recoding/ranking variables for the regression model used to est. missing rents*
*********************************************************************************

*roofing material*
gen g09a=.
replace g09a=1 if g09==5					/*recoding ..... from 5 to 1*/
replace g09a=2 if g09==1					/*recoding ..... from 1 to 2*/
replace g09a=3 if g09==2					/*recoding ..... from 2 to 3*/
replace g09a=4 if g09==3					/*recoding ..... from 3 to 4*/
replace g09a=5 if g09==4					/*recoding ..... from 4 to 5*/
replace g09a=6 if g09==6					/*recoding ..... from 6 to 6*/
replace g09a=2 if g09a==1 & g09a~=. & g09a~=0  /* recoding plastic sheeting into grass thatching*/
replace g09a=3 if (g09a==4|g09a==5) & g09a~=. & g09a~=0 /* recoding clay tiles and concrete into iron sheets*/
replace g09a=. if g09a==6 /*recoding other to missing*/
replace g09a=0 if g09a==2
replace g09a=1 if g09a==3
label define g09a 0 "grass/plastic" 1 "iron"
label values g09a g09a

*floor material*
gen g10a=.
replace g10a=1 if g10==1					/*recoding ..... from 1 to 1*/
replace g10a=2 if g10==2					/*recoding ..... from 2 to 2*/
replace g10a=3 if g10==4					/*recoding ..... from 4 to 3*/
replace g10a=4 if g10==3					/*recoding ..... from 3 to 4*/
replace g10a=5 if g10==5					/*recoding ..... from 5 to 5*/
replace g10a=6 if g10==6					/*recoding ..... from 6 to 6*/
replace g10a=2 if g10a==1 & g10a~=. & g10a~=0 /*recoding sand floor into smooth mud floor*/
replace g10a=3 if g10a==5 & g10a~=. & g10a~=0 /*recoding tiles into wood floor*/
replace g10a=. if g10==6 /*recoding other to missing*/
label define g10a 2 "smooth mud" 3 "wood" 4 "cement"
label values g10a g10a

* room numbers *
replace g11=3 if g11==34					/*replacing outliers for room numbers*/

* electricity
replace g20=0 if g20==2
assert g20==1 | g20==. | g20==0

*source of water*
replace g30=	2	if g30o=="ANOTHER HH PIPE"
replace g30=	2	if g30o=="ANOTHR HH PIPE"
replace g30=	2	if g30o=="BOUGHT FOR NEGH"
replace g30=	2	if g30o=="BROKEN"
replace g30=	2	if g30o=="BROKEN PIPE LIN"
replace g30=	2	if g30o=="BROKEN PIPELINE"
replace g30=	2	if g30o=="BUY FROM NEIBOR"
replace g30=	2	if g30o=="BUY FROM NEIBOU"
replace g30=	2	if g30o=="BUY FROM NEIGHB"
replace g30=	2	if g30o=="BUYING WATER"
replace g30=	2	if g30o=="CCAP"
replace g30=	7	if g30o=="COMM OPEN WELL"
replace g30=	4	if g30o=="COMMUNAL PROTEC"
replace g30=	4	if g30o=="COMMUNAL PUMP"
replace g30=	7	if g30o=="COMMUNAL WELL"
replace g30=	7	if g30o=="COMUNAL WELL"
replace g30=	7	if g30o=="DAMBO WELLS"
replace g30=	7	if g30o=="DRAW FROM NEIGH"
replace g30=	7	if g30o=="FROM NEIGHBOUR"
replace g30=	2	if g30o=="FROM SCHOOL"
replace g30=	2	if g30o=="LANDLORD TAP"
replace g30=	2	if g30o=="LANDLORD'STAP"
replace g30=	2	if g30o=="LANDLORDS PIPE"
replace g30=	2	if g30o=="LANDLORDS TAP"
replace g30=	2	if g30o=="LANLORDS PIPE"
replace g30=	2	if g30o=="NEIBOURS"
replace g30=	2	if g30o=="NEIGBOURS"
replace g30=	2	if g30o=="NEIGHB PIPE"
replace g30=	2	if g30o=="NEIGHBORS PIPE"
replace g30=	2	if g30o=="NEIGHBOUR"
replace g30=	2	if g30o=="NEIGHBOUR PIPE"
replace g30=	2	if g30o=="NEIGHBOUR STAND"
replace g30=	2	if g30o=="NEIGHBOUR'PIPE"
replace g30=	2	if g30o=="NEIGHBOURS"
replace g30=	2	if g30o=="NEIGHBOURS PIPE"
replace g30=	2	if g30o=="NEIGHBOURS TAP"
replace g30=	2	if g30o=="NEIGHBUR STAND"
replace g30=	2	if g30o=="NEIHBOURS"
replace g30=	7	if g30o=="OTHER PPLS WELL"
replace g30=	7	if g30o=="PERSONAL  WELL"
replace g30=	7	if g30o=="PERSONAL WELL"
replace g30=	2	if g30o=="PIPE"
replace g30=	2	if g30o=="PIPE FROM NEIGH"
replace g30=	2	if g30o=="PIPE WATER"
replace g30=	7	if g30o=="PRIVATE PAIL"
replace g30=	2	if g30o=="PRIVATE PIPE"
replace g30=	4	if g30o=="PRIVATE PUMP"
replace g30=	4	if g30o=="PRIVATE WELL"
replace g30=	4	if g30o=="PROTECTED WALL"
replace g30=	7	if g30o=="PROTECTED WELL"
replace g30=	7	if g30o=="RENT FROM NEGHB"
replace g30=	4	if g30o=="SCHOOL HANDPUMP"
replace g30=	7	if g30o=="STREAM"
replace g30=	7	if g30o=="STREAM WELL"
replace g30=	2	if g30o=="TAP"
replace g30=	2	if g30o=="WATER PIPE"
replace g30=	2	if g30o=="WATERBOARD TAP"
replace g30=	7	if g30o=="WELL"
replace g30=	4	if g30o=="WELL AT HOME"

replace g30=2 if g30==3 & g30~=. & g30~=0	/*recoding communal piped water to pipe outside house*/
replace g30=4 if (g30==5|g30==6) & g30~=. & g30~=0 /*recoding personnal pump, comm. pum and protected spring into one value label*/
replace g30=7 if (g30==8|g30==9|g30==10) & g30~=. & g30~=0 /*recoding unprotected personnal/comm. well, spring reservior*/
replace g30=. if g30==11 /*recoding other to missing*/

*toilet facilities*
replace g36=5	if g36o=="AMID SMALL HEDG"
replace g36=5	if g36o=="BUSH"
replace g36=5	if substr(g36o,1,4)=="DAUG"
replace g36=5	if g36o=="GRASS"
replace g36=5	if g36o=="GRASS WALL"
replace g36=2	if g36o=="LATRINE IN BUSH"
replace g36=2	if substr(g36o,1,4)=="NEIG"
replace g36=1	if g36o=="NEW  TOILET"
replace g36=1	if g36o=="PARENT`S TOILET"
replace g36=1	if g36o=="SCHOOL TOILET"
replace g36=2	if g36o=="UNFINISHED"
replace g36=5	if g36o=="USE BUSH"
replace g36=2	if substr(g36o,1,4)=="WIFE"
replace g36=2 if (g36==3|g36==4) & g36~=. & g36~=0	/*recoding latrine w/roof, latrine w/o roof into latrine tradition*/
replace g36=. if g36==6 /*recoding other as missing*/

sort case_id
tempfile housing
save `housing',replace

*************************************************************************************
* MERGE WITH INTERVIEW DATE & HH WEIGHTS
*************************************************************************************
use `idate'
sort case_id
merge case_id using `housing'
assert _m==3 /* every hh should appear in both data sets */
drop _m

gen area=1 if reside==0 			/* urban */
replace area=2 if reside==1 & region==1 	/* Rural north  */
replace area=3 if reside==1 & region==2 	/* Rural center */
replace area=4 if reside==1 & region==3 	/* Rural south  */

* create month variable from 3-15 that will be used to merge with price index data
replace month=13 if year==2005 & month==1
replace month=14 if year==2005 & month==2
replace month=15 if year==2005 & month==3
tab month
assert month>2 & month<16
keep region reside area case_id dist g01 g07 g09a g10a g11 g20 g30 g36 nom* rent hhw month
sort area month
save `housing',replace
*************************************************************************************
* MERGE WITH PRICE INDEX TO DEFLATE RENTS
*************************************************************************************
use "$dataoth3\price_index.dta", clear
keep area month price
sort area month
merge area month using `housing'
assert _m==3
drop _m

* deflate rents (actual and estimated) into real values: MARCH 2004 URBAN PRICES
gen rent=nomrent/(price_index/100)
gen estrent=nomest/(price_index/100)
sum rent nomrent estrent nomest price

****************************************************************************
*creating a variable that has both imputed and actual rent (annual figures)*
****************************************************************************
gen housing=.						/* generating a variable that contains both imputed and actual rent paid*/
replace housing=rent 
replace housing=estrent  if estrent~=.

gen region1=(dist>=101 & dist<=105)				/*dummy variables 0 for north and otherwise for other regions*/
gen region2=(dist>=201 & dist<=209) 			/*dummy variable for central and otherwise for other regions*/

save `housing',replace

*************************************************************************************
* ESTIMATE MISSING HOUSING VALUE: N=108
* in order to use predlog to transform the log values for subsamples, have to separate the regressions.
* otherwise, it doesn't work right
*************************************************************************************
count if housing==.
tab g01 area if housing==. 

**URBAN RENTERS MISSING RENT**
use `housing',clear
gen housing2=housing     	if reside==0 & renting==1
gen ln_housing2=log(housing2) if reside==0 & renting==1
xi:reg ln_housing2 i.g07 i.g09a i.g10a g11 i.g20 i.g30 i.g36 region1 region2  [w=hhw]
predlog housing2 _Ig07_2 _Ig07_3 _Ig09a_1 _Ig10a_3 _Ig10a_4 _Ig20_1 _Ig30_2 _Ig30_4 _Ig30_7 _Ig36_2 _Ig36_5 g11 region1 region2  
/*predicting actual house rent urban*/
sum YHTNAIVE housing2 		if reside==0 & renting==1,det
replace housing=YHTNAIVE 	if reside==0 & renting==1 & housing==.
drop YH* housing2 ln_housing2 _I*
save `housing',replace

**RURAL RENTERS MISSING RENT**
use `housing',clear
gen housing2=housing     	if reside==1 & renting==1
gen ln_housing2=log(housing2) if reside==1 & renting==1
xi:reg ln_housing2 i.g07 i.g09a i.g10a g11 i.g20 i.g30 i.g36 region1 region2  [w=hhw]
predlog housing2 _Ig07_2 _Ig07_3 _Ig09a_1 _Ig10a_3 _Ig10a_4 _Ig20_1 _Ig30_2 _Ig30_4 _Ig30_7 _Ig36_2 _Ig36_5 g11 region1 region2  
/*predicting actual house rent urban*/
sum YHTNAIVE housing2		if reside==1 & renting==1,det
replace housing=YHTNAIVE 	if reside==1 & renting==1 & housing==.
drop YH* housing2 ln_housing2 _I*
save `housing',replace

**URBAN NONRENTERS MISSING RENT**
use `housing',clear
gen housing2=housing     	if reside==0 & renting==0
gen ln_housing2=log(housing2) if reside==0 & renting==0
xi:reg ln_housing2 i.g07 i.g09a i.g10a g11 i.g20 i.g30 i.g36 region1 region2  [w=hhw]
predlog housing2 _Ig07_2 _Ig07_3 _Ig09a_1 _Ig10a_3 _Ig10a_4 _Ig20_1 _Ig30_2 _Ig30_4 _Ig30_7 _Ig36_2 _Ig36_5 g11 region1 region2  
/*predicting actual house rent urban*/
sum YHTNAIVE housing2		if reside==0 & renting==0,det
replace housing=YHTNAIVE 	if reside==0 & renting==0 & housing==.
drop YH* housing2 ln_housing2 _I*
save `housing',replace

**RURAL NONRENTERS MISSING RENT**
use `housing',clear
gen housing2=housing     	if reside==1 & renting==0
gen ln_housing2=log(housing2) if reside==1 & renting==0
xi:reg ln_housing2 i.g07 i.g09a i.g10a g11 i.g20 i.g30 i.g36 region1 region2  [w=hhw]
predlog housing2 _Ig07_2 _Ig07_3 _Ig09a_1 _Ig10a_3 _Ig10a_4 _Ig20_1 _Ig30_2 _Ig30_4 _Ig30_7 _Ig36_2 _Ig36_5 g11 region1 region2  
/*predicting actual house rent urban*/
sum YHTNAIVE housing2		if reside==1 & renting==0,det
replace housing=YHTNAIVE 	if reside==1 & renting==0 & housing==.
drop YH* housing2 ln_housing2 _I*

ren housing realhousing
gen housing=(price_index/100)*realhousing
label var housing "Nominal annual housing valuation"
*************************************
*replacing outliers for rent value*
*************************************
bys reside: egen medrent=median(housing) 					/*generating median for imputed rent for urban by district*/	
replace housing=medrent if housing>500000 & housing~=. 		/*replacing imputed rent outliers for urban by median */

keep  case region reside area dist hhw price_index nom* rent estrent renting housing realhousing g* 
order case region reside area dist hhw price_index nom* rent estrent renting housing realhousing g* 
sort case
by case: assert _N==1
label data "Value of Housing"
note: Housing valuation based on actual rents (for renters) and self-reported/estimated rents for non-renters
note: 108 households missing housing valuation.  Imputted values are estimated from regressions
note: This data set includes housing characteristics since these are used in the regression work for the note on housing valuation alternatives for the consum aggregate.

gen exp_cat041=housing if renting==1 /* RENTERS: COICOP CAT 041 */
gen exp_cat042=housing if renting==0 /* NONRENTERS: COICOP CAT 042 */
qui for var exp_cat*: replace X=0 if X==.
* assert everyone has either rental or est rent values
assert exp_cat041+exp_cat042~=0

save "$dataoth2\expagg_housing",replace

log close
