***************************************************************************************
* This do-file creates consumption expenditure aggregate for non food expenditure
* Sections J, K, L, C, D, G, M
* 
*  INPUT DATA SETS:
*    	sec_j1.dta sec_j2.dta, sec_k.dta, sec_l.dta, sec_m.dta
*    	sec_c.dta , sec_d.dta, sec_g.dta (Original data)
*      
*  OUTPUT DATA SETS:
* 	expagg_nonfood
*
*******************************************************************************************
capture log close
clear all
log using "$output\expagg_nonfood", text replace

**********************************************
* EDUCATION  Section C
**********************************************
* Section C Q30
* The total expenditure on education is taken to be either the sum of the reported education 
* expenditure sub-categories (a - g) or the total reported in the last column, whichever is greater.

use "$data\sec_c.dta", clear
	
*replacing outliers for education expenditures*
bys c21: egen med=median(c30a) if c30a~=0 		/*generating median for tuition by type of sch. attended*/	
replace c30a=med if c30a>300000 & c30a~=.		/*replacing tuition outliers by median for type of school*/
drop med
egen med=median(c30b) if c30b~=0 & c21<=26	 	/*generating median for books for primary & secondary schools*/	
replace c30b=med if c30b>10000 & c30b~=. & c21<=26 /*replacing book expenditure outliers by median for primary & secondary*/
drop med
egen med=median(c30e) if c30e~=0 					/*median for sch. maint*/	
replace c30e=med if c30e>2000 & c30e~=.				/*replacing sch. maintenance expenditure outliers by median*/
drop med
egen med=median(c30f) if c30f~=0 				/*med. for parent Ass.*/
replace c30f=med if c30f>2500 & c30f~=. 			/*replacing parent ass. median*/
drop med

* computing education expenditures for individuals
egen exp_cat101= rsum(c30a c30b c30c c30d c30e c30f c30g) if (c30a~=.| c30b~=.| c30c~=.| c30d~=.| c30e~=.| c30f~=.| c30g~=.|total~=.)
replace exp_cat101=total if (exp_cat < total) & exp_cat~=. & total~=.	/*exp_educ(total individual educ expenditures)*/

*computing education expenditures for the household*
collapse (sum) exp_cat ,by (case_id)			/*adding all individual educ expenditures at household level*/
keep case_id exp_cat
tempfile sec_c
save `sec_c'

************************************************************
* HEALTH EXPENDITURE - Section D questions D12-D14, D16,D19* 
************************************************************
use "$data\sec_d.dta", clear

*replacing outliers for individual cases*
bys dist: egen med=median(d12) if d12~=0 		/*generating median for illness exp. in past 4wks by district*/	
replace d12=med if d12>2000 & d12~=.			/*replacing illness expend. outliers by median for district*/
drop med
bys dist: egen med=median(d13) if d13~=0 		/*generating median for medicare in past 4wks by district*/	
replace d13=med if d13>1500 & d13~=.			/*replacing medicare outliers by median for district*/
drop med
bys dist: egen med=median(d14) if d14~=0 		/*generating median for nonprescribed med. in past 4wks by district*/	
replace d14=med if d14>1500 & d14~=.			/*replacing nonprescribed expend. outliers by median for district*/
drop med
bys dist: egen med=median(d19) if d19~=0 		/*generating median for trad. healer exp. in during past 12 months by district*/	
replace d19=med if d19>5000 & d19~=.			/*replacing trad. healer expend. outliers by median for district*/
drop med

*annualizing illness and nonprescribed expenditures
qui for var d12 d13 d14: replace X=X*13

*computing individual health expenditures
gen exp_cat061= d14	/* annual  */
gen exp_cat062= d16	/* annual  */
egen exp_cat063=rsum(d12 d13 d19)	/* annual  */

*computing household level health expenditures*
collapse (sum) exp_cat*,by(case_id )	/*adding up all household expenditures*/
keep case_id exp_cat*
tempfile sec_d
save `sec_d'

*********************************************************************		
*Computing Household Utilities (*questions g19, g22, g26, g29, g35*)
*********************************************************************
use "$data\sec_g.dta", clear

* electricity & firewood: COICOP 045

*Expenditures on fuel wood (g19)*
bys  dist:egen median=median(g19)					/* generating a median for fuelwood exp. [g19]*/
replace g19=median if g19>1000 & g19~=.				/*replacing wood outliers*/ 
gen wood=g19*52 								/*generating annual wood expenditures*/

*Electricity Outliers 
replace g23b=5    if g23b==6 & g22==200						/* recording year instead of month (MK200)*/
replace g23a=.	if g23a==99 
gen elec=.		   							/*generating electricity variable- converted annually*/
replace elec=g22*13 	if g23b==4 & g23a==4 			/* 4 weeks   */
replace elec=g22*12 	if g23b==5 & g23a==1 			/* one month */
replace elec=g22*6  	if g23b==5 & g23a==2 			/* 2 months */
replace elec=g22*4  	if g23b==5 & g23a==3 			/* 3 months */
replace elec=g22*3  	if g23b==5 & g23a==4 			/* 4 months */
replace elec=g22*12/5  	if g23b==5 & g23a==5 			/* 5 months */
replace elec=g22*12/8  	if g23b==5 & g23a==8 			/* 8 months */
replace elec=g22*2  	if g23b==5 & g23a==6 			/* 6 months */
replace elec=g22/2  	if g23b==6 & g23a==2 			/* 2 years */
bys region reside: egen medelec=median(elec)	if	elec~=0	/* generating a median for annual electricity exp.*/
replace elec=medelec if elec>100000 & elec~=. 				/* replacing elec. outliers*/
replace elec=medelec if g22>0 & g22~=. & g23b==.			/*replacing households with g22 greater tha zero but with missing g23b*/

egen exp_cat045_g=rsum(wood elec)

**************************************************
* phone: COICOP 081
* Land Line Phone
gen phone=.									/*generating phone bills and converting to annual bills*/
replace phone=g26*365 if g27==1 & g27b==3				/* 1 day */
replace phone=g26*52 if g27==1 & g27b==4 				/* 1 week */
replace phone=g26*13 if g27==4 & g27b==4 				/* 4 weeks */
replace phone=g26*12 if g27==1 & g27b==5 				/* 1 month */
replace phone=g26*4  if g27==3 & g27b==5 				/* 3 months */
replace phone=g26*6  if g27==2 & g27b==5 				/* 2 months */
replace phone=g26*26 if g27==2 & g27b==4 				/* 2 weeks */
egen medphone=median(phone)				/*generating median for phone by district*/
replace phone=medphone if phone>150000 & phone~=.		/*replacing outliers for phone expenditures*/ 
* Cell Phone
gen cell=.									/*generating cell phone bills*/
replace cell=g29*12							/*converting to annual bills*/
egen medcell=median(cell)	
replace cell=medcell if cell>150000 & cell~=.			/*replacing outliers for cell expenditures*/ 
egen exp_cat081_g=rsum(phone cell)
**************************************************
*Drinking water : COICOP exp_cat012
gen exp_cat012_g=g35*12
egen medwater=median(exp_cat012) if exp_cat012~=0				/*generating median for annual drinking water */
replace exp_cat012=medwater if exp_cat012>60000 & exp_cat012~=.		/*replacing annual drinking water outliers by median*/
**************************************************
qui for var exp_cat045 exp_cat081 exp_cat012: replace X=0 if X==.
keep case_id exp_cat*
sort case_id
tempfile sec_g
save  `sec_g'

**********************************************
* NONFOOD Section J last 7 days   
**********************************************

use "$data\sec_j1.dta", clear

* replacing outliers						
bys dist ta:egen med=median(j03a) if j02==101 & j03a~=0 	/* Charcoal*/
replace j03a=med if j03a>600 & j02==101 & j03a~=.
drop med
bys dist ta:egen med=median(j03a) if j02==102 & j03a~=0
replace j03a=med if j03a>400 & j02==102 & j03a~=.		/* Parafin/kerosene*/
drop med										
bys dist: egen med=median(j03a) if j02==103 & j03a~=0
replace j03a=med if j03a>200 & j02==103 & j03a~=.		/* tobacco*/
drop med										
bys dist ta:egen med=median(j03a) if j02==104	& j03a~=0	/* Matches */
replace j03a=med if j03a>100 & j02==104 & j03a~=.
drop med										
bys dist ta:egen med=median(j03a) if j02==106	& j03a~=0	/*Public transport */
replace j03a=med if j03a>4000 & j02==106 & j03a~=.
drop med										

* charcoal, parrafin, matches: COICOP 3-DIGIT CODE 045
gen exp_cat045_j1=j03a if j02==101 | j02==102 | j02==104
replace j03a=. if j02==101 | j02==102 | j02==104
* tobacco: COICOP 3-DIGIT CODE 022
gen exp_cat022=j03a if j02==103
replace j03a=. if j02==103
* public transport: COICOP 3-DIGIT CODE 073
gen exp_cat073=j03a if j02==106
replace j03a=. if j02==106
* newspapers/magazines: COICOP 3-DIGIT CODE 095
gen exp_cat095_j1=j03a if j02==105
replace j03a=. if j02==105

* make sure all categories were assigned an exp_cat.

qui for var exp_cat* : replace X=X*52					/*Annualizing the value*/
collapse (sum) exp_cat* , by(case_id )
sort case_id
tempfile sec_j1
save `sec_j1'

**********************************************
* NONFOOD Section J last month
**********************************************
use "$data\sec_j2.dta", clear
					
* exclude mortgage 
replace j03b =.   if j02==216 				
* exclude donations
replace j03b =.   if j02==211

* replacing outliers
bys dist ta:egen med=median(j03b) 	if j02==201 & j03b~=0 		/* milling fees, grain */ 
replace j03b=med 	if j03b>1000 & j02==201 & j03b~=.
drop med										
bys dist ta:egen med=median(j03b) if j02==202 & j03b~=0		/* bar soap (body or clothes) */ 
replace j03b=med if j03b>1000 & j02==202 & j03b~=.
drop med										
bys dist ta:egen med=median(j03b) if j02==203 & j03b~=0		/* clothes powder soap */ 
replace j03b=med if j03b>1000 & j02==203 & j03b~=.
drop med										
bys dist ta:egen med=median(j03b) if j02==204 & j03b~=0		/* toothpaste, toothbrush */
replace j03b=med if j03b>500 & j02==204 & j03b~=.
drop med										
bys dist ta:egen med=median(j03b) if j02==205 & j03b~=0		/* toilet paper */ 
replace j03b=med if j03b>1000 & j02==205 & j03b~=.
drop med										
bys dist ta:egen med=median(j03b) if j02==206 & j03b~=0		/* skin creams, vaseline and glycerin */
replace j03b=med if j03b>750 & j02==206 & j03b~=.
drop med										
bys dist ta:egen med=median(j03b) if j02==207 & j03b~=0	/* other personal products */ 
replace j03b=med if j03b>1000 & j02==207 & j03b~=.
drop med										
bys dist ta:egen med=median(j03b) if j02==208 & j03b~=0	/* household cleaning products */
replace j03b=med if j03b>1000 & j02==208 & j03b~=.
drop med										
bys dist:egen med=median(j03b) if j02==209 & j03b~=0		/* light bulbs */
replace j03b=med if j03b>300 & j02==209 & j03b~=.		
drop med										
bys dist:egen med=median(j03b) if j02==210 & j03b~=0		/* postage stamps or other postal fees */
replace j03b=med if j03b>200 & j02==210 & j03b~=.
drop med										
bys dist:egen med=median(j03b) if j02==212 & j03b~=0		/* petrol/ diesel */
replace j03b=med if j03b>25000 & j02==212 & j03b~=.
drop med										
egen med=median(j03b) if j02==213 & j03b~=0			/* Vehicle servicing */
replace j03b=med if j03b>30000 & j02==213 & j03b~=.
drop med										
bys dist ta:egen med=median(j03b) if j02==214 & j03b~=0	/* bicycle repair  */
replace j03b=med if j03b>2500 & j02==214 & j03b~=.
drop med										
bys dist:egen med=median(j03b) if j02==215 & j03b~=0		/* wages for household servants */ 
replace j03b=med if j03b>10000 & j02==215 & j03b~=.
drop med										
bys dist ta:egen med=median(j03b) if j02==218 & j03b~=0	/* repairs to household and personal items */ 
replace j03b=med if j03b>2000 & j02==218 & j03b~=.
drop med		

* repairs & maintenance to dwelling : it is a COICOP category but won't be included in the consumption aggregate
gen exp_cat043_j2=j03b if j02==217
replace j03b=. if j02==217	 			

* lightbulbs: COICOP 3-DIGIT 045
gen exp_cat045_j2=j03b if j02==209
replace j03b=. if j02==209	

* repairs to personal items: COICOP 3-digit 053
gen exp_cat053_j2=j03b if j02==218
replace j03b=. if j02==218

* milling fees, hh cleaning, wages to servants: COICOP 3-DIGIT 056
gen exp_cat056_j2=j03b if j02==201 | j02==208 | j02==215
replace j03b=. if j02==201 | j02==208 | j02==215

* patrol, motor veh repair, bicycle repair: COICOP 3-DIGIT 072
gen exp_cat072=j03b if j02==212 | j02==213 | j02==214
replace j03b=. if j02==212 | j02==213 | j02==214

* postage
gen exp_cat081_j2=j03b if j02==210
replace j03b=. if j02==210

* personal items
gen exp_cat122=j03b if j02==202|j02==203|j02==204|j02==205|j02==206|j02==207
replace j03b=. if j02==202|j02==203|j02==204|j02==205|j02==206|j02==207

* make sure all categories were assigned an exp_cat.
assert j03b==.

qui for var exp_cat*: replace X=X*12							/*Annualizing the value*/
collapse (sum) exp_cat*,by(case_id )
sort case_id
tempfile sec_j2
save `sec_j2'

**********************************************
* NONFOOD Section K last 3 months
**********************************************
use "$data\sec_k.dta", clear
* CORRECTION
replace k02=325 if k0a=="Lady's shoes" & k02==.
assert k02~=.

* replacing outliers
bys dist ta:egen med=median(k03) if k02==301 & k03~=0		/* infant clothing, replace any value >MK2500 by a median */
replace k03=med if k03>2500 & k02==301 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==302 & k03~=0			/* baby nappies - replace any value >MK1500 by a median */
replace k03=med if k03>1500 & k02==302 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==303 & k03~=0		/* boy's trousers - replace any value >MK2000 by a median */
replace k03=med if k03>2500 & k02==303 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==304 & k03~=0		/* boy's shirts - replace any value >MK2500 by a median */
replace k03=med if k03>2500 & k02==304 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==306 & k03~=0		/* boy's undergarments - replace any value >MK1000 by a median */
replace k03=med if k03>1000 & k02==306 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==307 & k03~=0		/* boy's other clothing - replace any value >MK2200 by a median */
replace k03=med if k03>2200 & k02==307 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==308 & k03~=0		/* men's trousers - replace any value >MK5000 by a median */
replace k03=med if k03>5000 & k02==308 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==309 & k03~=0		/* men's shirts, replace any value >MK3000 by a median */
replace k03=med if k03>3000 & k02==309 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==310 & k03~=0			/* men's jackets - replace any value >MK5000 by a median */
replace k03=med if k03>5000 & k02==310 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==311 & k03~=0			/* men's undergarments - replace any value >MK1000 by a median */
replace k03=med if k03>1000 & k02==311 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==312 & k03~=0			/* other men's clothing - replace any value >MK3000 by a median */
replace k03=med if k03>3000 & k02==312 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==313 & k03~=0			/* girl's blouses - replace any value >MK3000 by a median */
replace k03=med if k03>3000 & k02==313 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==314 & k03~=0		/* girl's skirts - replace any value >MK2500 by a median */
replace k03=med if k03>2500 & k02==314 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==315 & k03~=0		/* girl's undergaments - replace any value >MK1000 by a median */
replace k03=med if k03>1000 & k02==315 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==316 & k03~=0		/* girl's other clothing - replace any value >MK4000 by a median */
replace k03=med if k03>4000 & k02==316 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==317 & k03~=0			/* ladies blouses - replace any value >MK3000 by a median */
replace k03=med if k03>3000 & k02==317 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==318 & k03~=0		/* chitenje cloth - replace any value >MK2000 by a median */
replace k03=med if k03>2000 & k02==318 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==319 & k03~=0		/* ladies skirts - replace any value >MK4100 by a median */
replace k03=med if k03>4100 & k02==319 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==320 & k03~=0			/* ladies undergarments - replace any value >MK1020 by a median */
replace k03=med if k03>1020 & k02==320 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==321 & k03~=0		/* ladies other clothing - replace any value >MK6000 by a median */
replace k03=med if k03>6000 & k02==321 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==322 & k03~=0		/* boy's shoes - replace any value >MK3000 by a median */
replace k03=med if k03>3000 & k02==322 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==323 & k03~=0		/* men's shoes - replace any value >MK4500 by a median */
replace k03=med if k03>4500 & k02==323 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==323 & k03~=0		/* girl's shoes - replace any value >MK2000 by a median */
replace k03=med if k03>2000 & k02==324 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==325 & k03~=0			/* ladies shoes - replace any value >MK2000 by a median */
replace k03=med if k03>3000 & k02==325 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==326 & k03~=0		/* cloth, thread and other sewing materials - replace any value >MK3200 by a median */
replace k03=med if k03>3200 & k02==326 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==327 & k03~=0		/* laundry, dry cleaning and tailoring fees - replace any value >MK4000 by a median */
replace k03=med if k03>4000 & k02==327 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==328 & k03~=0			/* bowls, glassware, plates - replace any value >MK2000 by a median */
replace k03=med if k03>2000 & k02==328 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==329 & k03~=0		/* cooking utensils - replace any value >MK2500 by a median */
replace k03=med if k03>2500 & k02==329 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==330 & k03~=0		/* cleaning utensils - replace any value >MK450 by a median */
replace k03=med if k03>450 & k02==330 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==331 & k03~=0			/* torch/flashlights - replace any value >MK250 by a median */
replace k03=med if k03>250 & k02==331 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==332 & k03~=0		/* umbrella - replace any value >MK600 by a median */
replace k03=med if k03>600 & k02==332 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==333 & k03~=0		/* hurricane lump - replace any value >MK800 by a median */
replace k03=med if k03>800 & k02==333 & k03~=.
drop med
bys dist ta:egen med=median(k03) if k02==334 & k03~=0		/* stationery items (not for school) - replace any value >MK1000 by a median */
replace k03=med if k03>1000 & k02==334 & k03~=.
drop med
egen med=median(k03) if k02==335 & k03~=0				/* books (not for school) - replace any value >MK3500 by a median */
replace k03=med if k03>3500 & k02==335 & k03~=.
drop med
egen med=median(k03) if k02==336 & k03~=0				/* music or video cassette or cd - replace any value > MK5000 by a media */
replace k03=med if k03>5000 & k02==336 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==337 & k03~=0			/* tickets for sports/entertainment - replace any value >MK2000 by a median */
replace k03=med if k03>2000 & k02==337 & k03~=.
drop med
bys dist:egen med=median(k03) if k02==338 & k03~=0			/* household decorations - replace any value >MK7000 by a median */
replace k03=med if k03>7000 & k02==338 & k03~=.
drop med
egen med=median(k03) if k02==339 & k03~=0				/* night's lodging in resthouse or hotel - replace any value >MK3000 by a median */
replace k03=med if k03>3000 & k02==339 & k03~=.
drop med

* clothing : COICOP 3-DIGIT 031
gen     exp_cat031=k03 if (k02>=301 & k02<=321)|(k02>=326 & k02<=327)
replace k03=. if (k02>=301 & k02<=321)|(k02>=326 & k02<=327)
* Shoes:  : COICOP 3-DIGIT 032
gen     exp_cat032=k03 if (k02>=322 & k02<=325)
replace k03=. if (k02>=322 & k02<=325)
* House decorations  : COICOP 3-DIGIT 051
gen     exp_cat051_k=k03 if k02==338
replace k03=. if k02==338
* Bowls, cooking utensils: COICOP 3-DIGIT 054
gen     exp_cat054=k03 if k02==328|k02==329
replace k03=.  if k02==328|k02==329
* Torch, lamp: COICOP 3-DIGIT 055
gen     exp_cat055_k=k03 if k02==331|k02==333
replace k03=.  if k02==331|k02==333
* Cleaning utensils: COICOP 3-DIGIT 056
gen     exp_cat056_k=k03 if k02==330
replace k03=.  if k02==330
* Music/video cassette: COICOP 3-DIGIT 091
gen     exp_cat091_k=k03 if k02==336
replace k03=.  if k02==336
* Sports tickets: COICOP 3-DIGIT 094
gen     exp_cat094=k03 if k02==337
replace k03=.  if k02==337
* Stationary, books: COICOP 3-DIGIT 095
gen     exp_cat095_k=k03 if  k02==334|k02==335
replace k03=.  if k02==334|k02==335
* Nights lodging: COICOP 3-DIGIT 112
gen     exp_cat112=k03 if k02==339
replace k03=.  if k02==339
* Umbrella: COICOP 3-DIGIT 121
gen     exp_cat121=k03 if k02==332
replace k03=.  if k02==332

* make sure all categories were assigned an exp_cat.
assert k03==.  

qui for var exp_cat*: replace X=X*4						/*Annualizing the value*/
collapse (sum) exp_cat*,by(case_id )
sort case_id
tempfile sec_k
save `sec_k'

**********************************************
* NON-FOOD EXPENDITURE - Section  L last 12 months
**********************************************
* 4. Non-Food last 12 months without items 408, 411, 412, 413, 414, 415 

use "$data\sec_l.dta", clear


/* exclude council rates */
replace l03 =.   if l02==409
/* exclude losses to theft */
replace l03 =.   if l02==411 						
/*exclude fines/legal fees*/
replace l03=. if l02==412
/*exclude lobola costs*/
replace l03=. if l02==413
/*exclude marriage ceremony costs*/
replace l03=. if l02==414
/*exclude funeral costs*/
replace l03=. if l02==415
					
bys dist:egen med=median(l03) if l02==401 & l03~=0			/* carpets, rugs, drapes, curtains - replace any value >MK12000 by a median */
replace l03=med if l03>12000 & l02==401 & l03~=.
drop med
bys dist:egen med=median(l03) if l02==402 & l03~=0			/*  linen - replace any value >MK8000 by a median */
replace l03=med if l03>8000 & l02==402 & l03~=.
drop med
bys dist ta:egen med=median(l03) if l02==403 & l03~=0		/* mats for sleeping or for drying flour - replace any value >MK1500 by a median */
replace l03=med if l03>1500 & l02==403 & l03~=.
drop med
bys dist ta:egen med=median(l03) if l02==404 & l03~=0		/* mosquito nets - replace any value >MK1000 by a median */
replace l03=med if l03>1000 & l02==404 & l03~=.
drop med
bys dist ta:egen med=median(l03) if l02==405 & l03~=0		/* matresses - replace any value >MK10000 by a median */
replace l03=med if l03>10000 & l02==405 & l03~=.
drop med
bys dist ta:egen med=median(l03) if l02==406 & l03~=0		/* sport or hobby equipment - replace any value >MK8000 by a median */
replace l03=med if l03>8000 & l02==406 & l03~=.
drop med
egen med=median(l03) if l02==407 & l03~=0				/* film, film processing, camera - replace any value >MK4000 by a median */
replace l03=med if l03>4000 & l02==407 & l03~=.
drop med
bys dist:egen med=median(l03) if l02==409 & l03~=0			/* council rates - replace any value >MK9000 by a median */
replace l03=med if l03>9000 & l02==409 & l03~=.
drop med
bys dist:egen med=median(l03) if l02==410 & l03~=0			/* insurance, replace any value >MK80000 by a median */
replace l03=med if l03>80000 & l02==410 & l03~=. 
drop med

* building items, woodpoles or bamboo costs, grass for thatching roof or other use: COICOP 3-DIGIT 043
gen     exp_cat043_l=l03 if l02==416 | l02==417 | l02==408
replace l03=. if l02==416 | l02==417 | l02==408
* carpets, mattresses, mats, mos. nets: COICOP 3-DIGIT 051
gen     exp_cat051_l=l03 if l02==401 | l02==403 | l02==404 | l02==405
replace l03=. if l02==401 | l02==403 | l02==404 | l02==405
* Linens: COICOP 3-DIGIT 052
gen     exp_cat052=l03 if l02==402
replace l03=. if l02==402
* Film processing: COICOP 3-DIGIT 091
gen     exp_cat091_l=l03 if l02==407
replace l03=. if l02==407
* Sports: COICOP 3-DIGIT 092
gen     exp_cat092=l03 if l02==406
replace l03=. if l02==406
* Insurance: COICOP 3-DIGIT 124
gen     exp_cat124=l03 if l02==410
replace l03=. if l02==410

* make sure all categories were assigned an exp_cat.
assert l03==.  

collapse (sum) exp_cat* ,by(case_id)
sort case_id
tempfile sec_l
save `sec_l'

**********************************************
*  DURABLES - Section M
**********************************************
use "$data\sec_m1.dta", clear
*replacing dont know with missing for age of product
replace m04=. if m04==99
*dropping production durables and keeping consumption durables  
drop if (m02==518|m02==519)
*dropping observation with no or too little information
drop if m01a==2				/*products not owned*/
drop if m04==. & m05==.			/*items with no age nor value*/
drop if m03==. & m04==. 		/*households with no age and quantum given*/
*replacing outliers in values
bys m02a:egen med1=median(m05) 
replace m05=med1 if m05>1000 	& m05~=. 	& m02==501 
replace m05=med1 if m05>20000 	& m05~=. 	& m02==502 
replace m05=med1 if m05>10000 	& m05~=. 	& m02==503 
replace m05=med1 if m05>10000 	& m05~=. 	& m02==504
replace m05=med1 if m05>8000 	& m05~=. 	& m02==505
replace m05=med1 if m05>10000 	& m05~=. 	& m02==506
replace m05=med1 if m05>8000 	& m05~=. 	& m02==507
replace m05=med1 if m05>35000 	& m05~=. 	& m02==508
replace m05=med1 if m05>40000 	& m05~=. 	& m02==509
replace m05=med1 if m05>20000 	& m05~=. 	& m02==510
replace m05=med1 if m05>3000 	& m05~=. 	& m02==511
replace m05=med1 if m05>50000 	& m05~=. 	& m02==512
replace m05=med1 if m05>50000 	& m05~=. 	& m02==513
replace m05=med1 if m05>50000 	& m05~=. 	& m02==514
replace m05=med1 if m05>20000 	& m05~=. 	& m02==515
replace m05=med1 if m05>150000 	& m05~=. 	& m02==516
replace m05=med1 if m05>500000 	& m05~=.	& m02==517

*replacing outliers in number of items owned
bys m02a:egen med2=median(m03)
replace m03=med2 if m03>=7 	& m03~=. 	& m02==501
replace m03=med2 if m03>=10 	& m03~=. 	& m02==502
replace m03=med2 if m03>=10 	& m03~=.  	& m02==503
replace m03=med2 if m03>=20 	& m03~=.  	& m02==504
replace m03=med2 if m03>=5 	& m03~=.  	& m02==507
replace m03=med2 if m03>=5 	& m03~=. 	& m02==508
replace m03=med2 if m03>=5 	& m03~=. 	& m02==512
replace m03=med2 if m03>=10 	& m03~=. 	& m02==515
replace m03=med2 if m03>=4 	& m03~=. 	& m02==517

*replacing missing number of items with median
bys m02:replace m03=med2 if m03==.
*replacing values for households that own item but failed to give a value
replace m05=med1 if (m05==.|m05==0)
*replacing age for households that failed to  estimate age
bys m02a:egen med3=median(m04)
replace m04=med3 if m04==.
*Calculating remaning life time 
bys  m02a:egen avt=mean( m04a)				/*Average age of products*/
gen avl=2*avt							/*average lifetime of products*/

*** AVERAGE LIFETIMES
preserve
collapse (mean) avl (sum) m01a, by(m0a m02a)
replace avl=round(avl,.1)
sort m02a
list m02a m0a avl m01a,noobs nol
restore

gen rl=avl-m04a							/*remaing lifetime of product*/
replace rl=2 if rl<=2						/*replacing remaining lifetime with minimum 2 years*/

* Calculating estimated yearly value of goods
gen yvalue=m05a/rl						
gen sec_m=m03a*yvalue

* appliances: COICOP 3-digit code 053
gen exp_cat053_m=sec_m if m02==506|m02==510|m02==511|m02==512|m02==513|m02==514
replace sec_m =. if m02==506|m02==510|m02==511|m02==512|m02==513|m02==514
* mortatr/pestle: COICOP 3-digit code 055
gen exp_cat055_m=sec_m if m02==501
replace sec_m =. if m02==501
* furniture: COICOP 3-digit code 056
gen exp_cat056_m=sec_m if m02==502|m02==503|m02==504|m02==505
replace sec_m =. if m02==502|m02==503|m02==504|m02==505
* bike/scooter/motorcycle: COICOP 3-digit code 071
gen exp_cat071=sec_m if m02==515|m02==516|m02==517
replace sec_m =. if m02==515|m02==516|m02==517
* Radio/tape & cd player/television: COICOP 3-digit code 091
gen exp_cat091_m=sec_m if m02==507|m02==508|m02==509
replace sec_m =. if m02==507|m02==508|m02==509

* confirm that all iems have been assigned exp_cat
assert sec_m==.
collapse (sum) exp_cat*,by(case_id)
sort case_id
tempfile sec_m
save `sec_m'

***********************************************************************************
***********************************************************************************
use `sec_c'
merge case using `sec_d'
assert _m==3
drop _m
sort case
merge case using `sec_g'
assert _m==3
drop _m
sort case
merge case using `sec_j1'
assert _m==3
drop _m
sort case
merge case using `sec_j2'
assert _m==3
drop _m
sort case
merge case using `sec_k'
assert _m==3
drop _m
sort case
merge case using `sec_l'
assert _m==3
drop _m
sort case
merge case using `sec_m'
assert _m~=2
* hhs with no durables
qui for var exp_cat*m exp_cat071 : replace X=0 if X==. & _m==1
drop _m
sort case

save "$dataoth2\expagg_nonfood",replace

log close

